@@ -7,14 +7,18 @@ extern "C" {
 bool_t	call_game_thread_create( void *(*func)( void * ) );
 void	call_gui_map_cont_exec_set( bool_t flagExec );
 void	call_gui_menu_draw( draw_menu_t *data );
-void	call_gui_menu_wipe();
+void	call_gui_menu_wipe( void );
 void	call_set_mouse_dflt_menu( long sel_n );
-void	call_pcg_dun_reset();
-void	call_pcg_dun_reset_update_flg();
+void	call_gui_message_set_flag_more( bool_t flag );
+void	call_gui_message_draw( void );
+void	call_gui_num_draw( long *n, long min, long max, long figure );
+void	call_gui_num_wipe( void );
+void	call_pcg_dun_reset( void );
+void	call_pcg_dun_reset_update_flg( void );
 void	call_pcg_dun_draw( long map_x, long map_y, long map_w, long map_h );
 void	call_pcg_dun_scroll( long map_x, long map_y );
-void	call_stat_win_redraw();
-long	call_key_get_char();
+void	call_stat_win_redraw( void );
+long	call_key_get_char( void );
 
 #ifdef __cplusplus
 }
