@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.24 2006/08/18 08:00:42 bowkenken Exp $
+* $Id: call.cpp,v 1.26 2006/09/26 18:12:20 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -125,7 +125,7 @@ void	call_gui_menu_draw( draw_menu_t *data )
 * ˥塼ɥĤ
 ***************************************************************/
 
-void	call_gui_menu_wipe()
+void	call_gui_menu_wipe( void )
 {
 #ifdef D_WS
 	if( !g_flg_init )
@@ -190,11 +190,138 @@ void	call_set_mouse_dflt_menu( long sel_n )
 #endif // D_GTK
 }
 
+/***************************************************************
+* å³ޡ
+***************************************************************/
+
+void	call_gui_message_set_flag_more( bool_t flag )
+{
+#ifdef D_WS
+#endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiMessage.setFlagMore( flag );
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
+}
+
+/***************************************************************
+* åɥ
+***************************************************************/
+
+void	call_gui_message_draw( void )
+{
+#ifdef D_WS
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	WSGIappDev()->lock();
+
+	gGuiMessage.draw();
+
+	WSGIappDev()->unlock();
+#endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiMessage.draw();
+	gGuiMessage.drawScrollBar();
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
+}
+
+/***************************************************************
+* ϥɥ
+***************************************************************/
+
+void	call_gui_num_draw( long *n, long min, long max, long figure )
+{
+#ifdef D_WS
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	WSGIappDev()->lock();
+
+	gGuiNum.draw( n, min, max, figure );
+
+	WSGIappDev()->unlock();
+#endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiNum.draw( n, min, max, figure );
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
+}
+
+/***************************************************************
+* ϥɥĤ
+***************************************************************/
+
+void	call_gui_num_wipe( void )
+{
+#ifdef D_WS
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	WSGIappDev()->lock();
+
+	gGuiNum.wipe();
+
+	WSGIappDev()->unlock();
+#endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiNum.wipe();
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
+}
+
 /***************************************************************
 * եåѥΥꥻå
 ***************************************************************/
 
-void	call_pcg_dun_reset()
+void	call_pcg_dun_reset( void )
 {
 #ifdef D_WS
 	if( !g_flg_init )
@@ -231,7 +358,7 @@ void	call_pcg_dun_reset()
 * ޥåפιե饰Υꥻå
 ***************************************************************/
 
-void	call_pcg_dun_reset_update_flg()
+void	call_pcg_dun_reset_update_flg( void )
 {
 #ifdef D_WS
 	if( !g_flg_init )
@@ -339,7 +466,7 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 * ơɥ
 ***************************************************************/
 
-void	call_stat_win_redraw()
+void	call_stat_win_redraw( void )
 {
 #ifdef D_WS
 	if( !g_flg_init )
@@ -363,7 +490,7 @@ void	call_stat_win_redraw()
 * return : Ϥ줿
 ***************************************************************/
 
-long	call_key_get_char()
+long	call_key_get_char( void )
 {
 	long	c = '\0';
 
