@@ -51,12 +51,17 @@ void	mnstr_drop_gold( mnstr_t *p );
 void	mnstr_drop_bone( mnstr_t *p );
 void	mnstr_drop_item( mnstr_t *p );
 void	set_find_all_mnstr( void );
+long	get_party_dun_max_lev( void );
 void	print_ls_mnstr( void );
 mnstr_kind_t	get_npc_kind_randm( void );
 char	*get_mnstr_mjr_name( char mjr );
 char	*get_mnstr_name( mnstr_kind_t mnstr_kind );
 mnstr_tab_t	*get_mnstr_tab( mnstr_kind_t mnstr_kind, long dun_lev );
 mnstr_tab_t	*get_mnstr_tab_rand( long dun_lev );
+mnstr_tab_t	*get_mnstr_tab_rand_dun_lev( long dun_lev );
+mnstr_tab_t	*get_mnstr_tab_rand_sub(
+	long dun_lev, bool_t flg_no_chk_max
+);
 mnstr_tab_t	*get_mnstr_tab_friendly( void );
 mnstr_tab_t	*get_towner_tab_rand( void );
 mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev );
