@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.176 2006/09/19 04:35:15 bowkenken Exp $
+* $Id: party.c,v 1.180 2007/01/16 18:37:45 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -38,7 +38,7 @@
 
 #define	MBR_NEAR_R	4
 
-#define	FRIEND_MAX_TURN	(TURN_A_DAY * 1)
+#define	FRIEND_MAX_TURN	(6 * TURN_PER_HOUR)
 
 #define	LS_MBR_NULL	LS_MBR_MAX_N
 
@@ -1898,32 +1898,54 @@ void	divide_gold( void )
 void	give_gold( mbr_t *mbr_from, mbr_t *mbr_to, gold_t gold )
 {
 	bool_t	flg_force;
-	gold_t	res_price, max;
+	gold_t	res_price, inn_price, max;
 
 	if( mbr_from == NULL )
 		return;
 	if( mbr_to == NULL )
 		return;
 
+	flg_force = FALSE;
+
 	/* Ѥ GOLD ϵݽʤ */
 
 	res_price = get_price_temple_resurrection( mbr_to );
-	flg_force = FALSE;
 	if( chk_flg( mbr_to->stat, FLG_STAT_DEAD )
 			&& (get_chr_gold( mbr_to ) < res_price)
 			&& (mbr_to->fx_data.friend_turn > 0) ){
 		flg_force = TRUE;
 	}
 
-	/* GOLD Τ */
+	/* 夯餤 GOLD ϵݤʤ */
 
-	if( mbr_to->fx_data.friend_turn > 0 ){
-		if( !flg_force ){
-			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
-					mbr_to->name );
-			return;
-		}
-	}
+	inn_price = get_price_inn( FALSE );
+	do {
+		if( mbr_from->fx_data.friend_turn > 0 )
+			break;
+		if( mbr_to->fx_data.friend_turn <= 0 )
+			break;
+		if( get_chr_gold( mbr_to ) + gold > inn_price )
+			break;
+
+		flg_force = TRUE;
+		break;
+	} while( 0 );
+
+	/* 礬ɤå */
+
+	do {
+		if( flg_force )
+			break;
+		if( mbr_from->fx_data.friend_turn <= 0 )
+			if( mbr_to->fx_data.friend_turn <= 0 )
+				break;
+
+		/* GOLD Τ */
+
+		print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
+				mbr_to->name );
+		return;
+	} while( 0 );
 
 	max = GOLD_MAX - get_chr_gold( mbr_to );
 	if( gold > max )
@@ -2770,7 +2792,7 @@ void	arrange_class( long class_n, long d )
 		p[0] = tmp;
 	} else {
 		for( n = class_n + 1; n < CLASS_MAX_N; n++ ){
-			if( p[n].n_name == N_MSG_NULL )
+			if( p[n].name[0] == '\0' )
 				break;
 
 			p[n - 1] = p[n];
